@@ -14,9 +14,14 @@ from ForMark.singleton import Singleton
 
 class ForLog(Singleton):
     def __init__(self, log_file_path="/logs/mark"):
-        print(log_file_path)
         logger.add(
-            log_file_path, format="{time:YYYY-MM-DD at HH:mm:ss} | {level} | {message}", filter="", level="INFO")
+            log_file_path,
+            format="{time:YYYY-MM-DD at HH:mm:ss} | {level} | {message}",
+            filter="",
+            level="INFO",
+            enqueue=True,  # 异步写入
+            retention="3 days"  # 一段时间后会清空
+        )
 
     @classmethod
     def logger_info(cls, *msg):
